diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/configuration/annotation/EnableBatchProcessing.java b/spring-batch-core/src/main/java/org/springframework/batch/core/configuration/annotation/EnableBatchProcessing.java
index e11e0a8f0..a5e2b8e97 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/configuration/annotation/EnableBatchProcessing.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/configuration/annotation/EnableBatchProcessing.java
@@ -205,8 +205,8 @@ public @interface EnableBatchProcessing {
String tablePrefix() default AbstractJdbcBatchMetadataDao.DEFAULT_TABLE_PREFIX;
/**
- * The maximum lenght of exit messages in the database.
- * @return the maximum lenght of exit messages in the database
+ * The maximum length of exit messages in the database.
+ * @return the maximum length of exit messages in the database
*/
int maxVarCharLength() default AbstractJdbcBatchMetadataDao.DEFAULT_EXIT_MESSAGE_LENGTH;
@@ -247,7 +247,7 @@ public @interface EnableBatchProcessing {
* Set the conversion service to use in the job repository and job explorer. This
* service is used to convert job parameters from String literal to typed values and
* vice versa.
- * @return the bean name of the conversion service to use. Defauls to
+ * @return the bean name of the conversion service to use. Defaults to
* {@literal conversionService}
*/
String conversionServiceRef() default "conversionService";
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/converter/DefaultJobParametersConverter.java b/spring-batch-core/src/main/java/org/springframework/batch/core/converter/DefaultJobParametersConverter.java
index 837ef458d..8af2b8764 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/converter/DefaultJobParametersConverter.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/converter/DefaultJobParametersConverter.java
@@ -38,7 +38,7 @@ import org.springframework.util.StringUtils;
* where:
*
*
- * - value: string literal repesenting the value
+ * - value: string literal representing the value
* - type (optional): fully qualified name of the type of the value. Defaults to
* String.
* - identifying (optional): boolean to flag the job parameter as identifying or not.
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/listener/CompositeChunkListener.java b/spring-batch-core/src/main/java/org/springframework/batch/core/listener/CompositeChunkListener.java
index f0becfc0c..7818ea313 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/listener/CompositeChunkListener.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/listener/CompositeChunkListener.java
@@ -32,7 +32,7 @@ public class CompositeChunkListener implements ChunkListener {
private OrderedComposite listeners = new OrderedComposite<>();
/**
- * Default constrcutor
+ * Default constructor
*/
public CompositeChunkListener() {
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/step/builder/AbstractTaskletStepBuilder.java b/spring-batch-core/src/main/java/org/springframework/batch/core/step/builder/AbstractTaskletStepBuilder.java
index 898e63ffe..11944a20f 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/step/builder/AbstractTaskletStepBuilder.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/step/builder/AbstractTaskletStepBuilder.java
@@ -200,7 +200,7 @@ public abstract class AbstractTaskletStepBuilder implements ItemProcessor, Initia
private List extends ItemProcessor, ?>> delegates;
/**
- * Default constrcutor
+ * Default constructor
*/
public CompositeItemProcessor() {
diff --git a/spring-batch-infrastructure/src/main/java/org/springframework/batch/item/support/CompositeItemStream.java b/spring-batch-infrastructure/src/main/java/org/springframework/batch/item/support/CompositeItemStream.java
index 61fbf3f4e..e773bf861 100644
--- a/spring-batch-infrastructure/src/main/java/org/springframework/batch/item/support/CompositeItemStream.java
+++ b/spring-batch-infrastructure/src/main/java/org/springframework/batch/item/support/CompositeItemStream.java
@@ -64,7 +64,7 @@ public class CompositeItemStream implements ItemStream {
}
/**
- * Default constrcutor
+ * Default constructor
*/
public CompositeItemStream() {
super();
diff --git a/spring-batch-infrastructure/src/main/java/org/springframework/batch/item/support/CompositeItemWriter.java b/spring-batch-infrastructure/src/main/java/org/springframework/batch/item/support/CompositeItemWriter.java
index 027583343..81d8590d8 100644
--- a/spring-batch-infrastructure/src/main/java/org/springframework/batch/item/support/CompositeItemWriter.java
+++ b/spring-batch-infrastructure/src/main/java/org/springframework/batch/item/support/CompositeItemWriter.java
@@ -45,7 +45,7 @@ public class CompositeItemWriter implements ItemStreamWriter, Initializing
private boolean ignoreItemStream = false;
/**
- * Default constrcutor
+ * Default constructor
*/
public CompositeItemWriter() {
diff --git a/spring-batch-infrastructure/src/main/java/org/springframework/batch/repeat/listener/CompositeRepeatListener.java b/spring-batch-infrastructure/src/main/java/org/springframework/batch/repeat/listener/CompositeRepeatListener.java
index 42d4e74f7..91b2d008e 100644
--- a/spring-batch-infrastructure/src/main/java/org/springframework/batch/repeat/listener/CompositeRepeatListener.java
+++ b/spring-batch-infrastructure/src/main/java/org/springframework/batch/repeat/listener/CompositeRepeatListener.java
@@ -34,7 +34,7 @@ public class CompositeRepeatListener implements RepeatListener {
private List listeners = new ArrayList<>();
/**
- * Default constrcutor
+ * Default constructor
*/
public CompositeRepeatListener() {
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/configuration/annotation/BatchRegistrar.java b/spring-batch-core/src/main/java/org/springframework/batch/core/configuration/annotation/BatchRegistrar.java
index 028cf53b3..3c8878fec 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/configuration/annotation/BatchRegistrar.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/configuration/annotation/BatchRegistrar.java
@@ -37,7 +37,7 @@ import org.springframework.core.type.AnnotationMetadata;
import org.springframework.util.StopWatch;
/**
* Base registrar that provides common infrastrucutre beans for enabling and using Spring
* Batch in a declarative way through {@link EnableBatchProcessing}.
*
* @author Mahmoud Ben Hassine
@@ -66,7 +66,7 @@ class BatchRegistrar implements ImportBeanDefinitionRegistrar {
registerJobOperator(registry, batchAnnotation);
registerAutomaticJobRegistrar(registry, batchAnnotation);
watch.stop();
- LOGGER.info(LogMessage.format("Finished Spring Batch infrastrucutre beans configuration in %s ms.",
+ LOGGER.info(LogMessage.format("Finished Spring Batch infrastructure beans configuration in %s ms.",
watch.getLastTaskTimeMillis()));
}
@@ -37,7 +37,7 @@ import org.springframework.core.type.AnnotationMetadata;
import org.springframework.util.StopWatch;
/**
- * Base registrar that provides common infrastrucutre beans for enabling and using Spring
+ * Base registrar that provides common infrastructure beans for enabling and using Spring
* Batch in a declarative way through {@link EnableBatchProcessing}.
*